/* $Id: unix.h,v 1.6 2004/08/14 23:23:47 jonas Exp $ */

#ifndef EL__OSDEP_UNIX_UNIX_H
#define EL__OSDEP_UNIX_UNIX_H

#ifdef CONFIG_UNIX

/* TODO */

#endif

#endif
